using System.Security.Authentication;
using FitConnect;
using FitConnect.Services;
using FluentAssertions;
using NUnit.Framework;

namespace E2ETests;

public class OAuthServiceTest {
    private string _clientId;
    private string _clientSecret;
    private OAuthService _oAuthService = null!;

    [OneTimeSetUp]
    public void OneTimeSetup() {
        (_clientId, _clientSecret) = HelperMethods.GetSecrets();
    }


    [SetUp]
    public void SetUp() {
        var endpoints = FitConnectEnvironment.Development;
        _oAuthService = new OAuthService(endpoints.TokenUrl);
    }

    [Test]
    public void GetAccessToken_ExpiresInShouldBe1800_WithoutScope() {
        var token = _oAuthService.AuthenticateAsync(_clientId, _clientSecret).Result;
        token.Should().NotBeNull();
        token!.ExpiresIn.Should().Be(1800);
        token.Scope.Should().Be("send:region:DE");
    }

    [Test]
    public void GetAccessToken_WrongCredentials_ThrowInvalidCredentialException() {
        var exception = Assert.ThrowsAsync<InvalidCredentialException>(() =>
            _oAuthService.AuthenticateAsync(_clientId, "WRONG")
        );
        exception!.Message.Replace(" ", "").Should().Contain("\"error\":\"invalid_client\"");
    }

    [Test]
    public void GetAccessToken_ScopeShouldMatch_WithScope() {
        var token = _oAuthService.AuthenticateAsync(_clientId, _clientSecret, "send:region:DE01010")
            .Result;
        token.Should().NotBeNull();
        token!.ExpiresIn.Should().Be(1800);
        token.Scope.Should().Be("send:region:DE01010");
    }
}
