using System;
using System.IO;
using System.Net;
using System.Reflection;
using DotNet.Testcontainers.Builders;
using DotNet.Testcontainers.Containers;
using FitConnect;
using FitConnect.Services;
using FluentAssertions;
using NUnit.Framework;

namespace E2ETests;

[Ignore("Not testable in docker container, take to long to run every time")]
public class ProxyTest {
    private Client _client;
    private TestcontainersContainer _container;
    private string _id;
    private string _secret;

    [OneTimeSetUp]
    public void OneTimeSetup() {
        var path = $"{Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location)}/proxy";
        Console.WriteLine($"Creating directory: {path}");
        Directory.CreateDirectory(path);
        (_id, _secret) = HelperMethods.GetSecrets();

        _container = new TestcontainersBuilder<TestcontainersContainer>()
            .WithImage("ubuntu/squid")
            .WithPortBinding("3128", "3128")
            .WithBindMount(path, @"/var/log/squid")
            .Build();
    }

    [SetUp]
    public void Setup() {
        _container.StartAsync().Wait();

        _client =
            new Client(FitConnectEnvironment.Development,
                    _id,
                    _secret)
                .WithProxy("localhost", 3128);
    }

    [Test]
    public void ContainerIsRunning() {
        _container.Should().NotBeNull();
        _container.State.Should().Be(TestcontainersState.Running);

        var client = new WebClient {
            Proxy =
                new WebProxy("http://localhost:3128")
        };
        client.DownloadString("https://www.fitko.de/").Should().NotBeNull();
    }

    [Test]
    public void RequestOAuthToken() {
        // Arrange
        var testUrl = FitConnectEnvironment.Development
            .TokenUrl;

        var oAuthService = new OAuthService(testUrl) {
            Proxy = new WebProxy("http://localhost:3128")
        };

        // Act
        var token = oAuthService.AuthenticateAsync(_id, _secret).Result;

        // Assert
        token.Should().NotBeNull();
    }

    [OneTimeTearDown]
    public void OneTimeTearDown() {
        _container.StopAsync().Wait();
    }
}
