using System;
using Autofac;
using FitConnect;
using FitConnect.Models;
using FluentAssertions;
using Microsoft.Extensions.Logging;
using MockContainer;
using NUnit.Framework;

namespace FluentApiTest;

public class FluentSenderTests {
    private Client _client = null!;
    private IContainer _container = null!;
    private readonly string clientId = "clientId";
    private readonly string clientSecret = "clientSecret";
    private ILogger? logger;

    [OneTimeSetUp]
    public void OneTimeSetup() {
        _container = Container.Create();
        logger = _container.Resolve<ILogger>();
    }

    [SetUp]
    public void Setup() {
        _client = new Client(
            FitConnectEnvironment.Development,
            clientId, clientSecret,
            container: _container,
            logger: logger);
    }

    [Test]
    public void FluentSender_ShouldNotThrowAnError_ArgumentExceptionLeikaKeyInvalid() {
        Assert.Throws<ArgumentException>(() => {
            _client.GetSender()
                .WithDestination(Guid.NewGuid().ToString())
                .WithServiceType("", "")
                .WithAttachments(Array.Empty<Attachment>())
                .WithData("")
                .Submit();
        })!.Message.Should().Be("Invalid leika key");
    }

    [Test]
    public void FluentSender_ShouldNotThrowAnError_MockingServicesWithData() {
        _client.GetSender()
            .WithDestination(Guid.NewGuid().ToString())
            .WithServiceType("", "urn:de:fim:leika:leistung:99400048079000")
            .WithAttachments(Array.Empty<Attachment>())
            .WithData("")
            .Submit();
    }

    [Test]
    public void FluentSender_ShouldNotThrowAnError_MockingServicesWithoutData() {
        _client.GetSender()
            .WithDestination(Guid.NewGuid().ToString())
            .WithServiceType("", "urn:de:fim:leika:leistung:99400048079000")
            .WithAttachments(Array.Empty<Attachment>())
            .Submit();
    }
}
