using System;
using System.Security.Cryptography.X509Certificates;
using Autofac;
using FitConnect;
using Microsoft.Extensions.Logging;
using MockContainer;
using NUnit.Framework;

namespace FluentApiTest;

public class FluentSubscriberPollingTests {
    private readonly string clientId = "clientId";
    private readonly string clientSecret = "clientSecret";
    private X509Certificate2 _certificate;
    private Client _client = null!;
    private IContainer _container = null!;
    private ILogger _logger;
    private MockSettings _mockSettings;

    [OneTimeSetUp]
    public void OneTimeSetup() {
        _container = Container.Create();
        _logger = _container.Resolve<ILogger>();
        _mockSettings = _container.Resolve<MockSettings>();
        if (_logger == null)
            throw new ArgumentException("Logger not injected");
    }

    [SetUp]
    public void SetUp() {
        _client = new Client(
            FitConnectEnvironment.Development, clientId,
            clientSecret, container: _container, logger: _logger);
    }

    [Test]
    public void FluentSubscriberPollSubmissions_Success() {
        var submissions = _client
            .GetSubscriber(_mockSettings.PrivateKeyDecryption, _mockSettings.PrivateKeySigning)
            .GetAvailableSubmissions();
    }
}
